"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeRcConfig = exports.writeRcConfig = exports.readRcConfig = void 0;
var path_1 = __importDefault(require("path"));
var fs_1 = __importDefault(require("fs"));
var os_1 = require("os");
function getHomeDirectory() {
    return (0, os_1.homedir)();
}
function createRcConfigDirectory() {
    var rcDirectory = path_1.default.join(getHomeDirectory(), '.mamorurc');
    if (!fs_1.default.existsSync(rcDirectory)) {
        fs_1.default.mkdirSync(rcDirectory);
    }
}
function getRcConfigPath() {
    return path_1.default.join(getHomeDirectory(), '.mamorurc', 'config.json');
}
function readRcConfig() {
    var rcPath = getRcConfigPath();
    if (fs_1.default.existsSync(rcPath)) {
        var rcConfigString = fs_1.default.readFileSync(rcPath, 'utf-8');
        try {
            var rcConfigJson = JSON.parse(rcConfigString);
            return rcConfigJson || {};
        }
        catch (err) {
            // eslint-disable-next-line no-console
            console.error('Error parsing rc config file', err);
            return {};
        }
    }
    return {};
}
exports.readRcConfig = readRcConfig;
function writeRcConfig(rcConfig) {
    var rcPath = getRcConfigPath();
    var rcConfigString = JSON.stringify(rcConfig, null, 2);
    createRcConfigDirectory();
    fs_1.default.writeFileSync(rcPath, rcConfigString);
}
exports.writeRcConfig = writeRcConfig;
/**
 * Remove the rc config file, useful for tests
 */
function removeRcConfig() {
    var rcPath = getRcConfigPath();
    fs_1.default.existsSync(rcPath) && fs_1.default.unlinkSync(rcPath);
}
exports.removeRcConfig = removeRcConfig;
//# sourceMappingURL=index.js.map