"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDaemonIdsFromPlaybook = exports.isValidPlaybookManifest = void 0;
var joi_1 = __importDefault(require("joi"));
var utils_1 = require("./utils");
var playbookSchema = joi_1.default.object({
    name: joi_1.default.string().required(),
    description: joi_1.default.string().optional(),
    on: joi_1.default.array().items(joi_1.default.object({
        daemonId: joi_1.default.string(),
        levels: joi_1.default.array().items(utils_1.joiSeverityValidator).min(1),
    })),
    tasks: joi_1.default.object().required(),
});
var isValidPlaybookManifest = function (logger, playbook) {
    logger.ok("Validating Playbook content");
    var error = playbookSchema.validate(playbook, { abortEarly: false }).error;
    if (error) {
        var formatted = (0, utils_1.formatJoiError)(error);
        logger.error(formatted);
        return false;
    }
    return true;
};
exports.isValidPlaybookManifest = isValidPlaybookManifest;
var getDaemonIdsFromPlaybook = function (playbook) {
    var daemonIds = [];
    for (var _i = 0, _a = playbook.on; _i < _a.length; _i++) {
        var on = _a[_i];
        if (on.daemonId) {
            daemonIds.push(on.daemonId);
        }
    }
    return daemonIds;
};
exports.getDaemonIdsFromPlaybook = getDaemonIdsFromPlaybook;
//# sourceMappingURL=playbook.js.map