import { DaemonMetadataContentQuery as MyDaemonMetadataContentQuery, DaemonParameterMap, Manifest } from '../../types';
import { DirectSecp256k1Wallet } from '@cosmjs/proto-signing';
import { Logger } from '../console';
import { MsgRegisterDaemon } from '@mamoru-ai/validation-chain-ts-client/dist/validationchain.validationchain/module';
import { MsgCreateDaemonMetadata, MsgCreateDaemonMetadataResponse, MsgCreatePlaybookResponse, MsgRegisterDaemonResponse, MsgUnregisterDaemonResponse, MsgUpdatePlaybookResponse } from '@mamoru-ai/validation-chain-ts-client/dist/validationchain.validationchain/types/validationchain/validationchain/tx';
import { Chain_ChainType } from '@mamoru-ai/validation-chain-ts-client/dist/validationchain.validationchain/types/validationchain/validationchain/chain';
import { DaemonMetadata } from '@mamoru-ai/validation-chain-ts-client/src/validationchain.validationchain/types/validationchain/validationchain/daemon_metadata';
import { AxiosInstance } from 'axios';
import { PlaybookDTO } from '@mamoru-ai/validation-chain-ts-client/dist/validationchain.validationchain/types/validationchain/validationchain/playbooks_dto';
type TxMsgData = {
    msgResponses: AnyMsg[];
};
type AnyMsg = {
    typeUrl: string;
    value: Uint8Array;
};
export type SdkVersion = {
    version: string;
    sdk: string;
};
export type Msgs = MsgRegisterDaemon | MsgCreateDaemonMetadata | TxMsgData | AnyMsg;
export type ValidationChainMsgs = MsgRegisterDaemon | MsgCreateDaemonMetadata | MsgCreateDaemonMetadataResponse | MsgRegisterDaemonResponse | MsgCreatePlaybookResponse | MsgUpdatePlaybookResponse;
declare class ValidationChainService {
    private readonly rpcUrl;
    private readonly privateKey;
    private readonly logger;
    /**
     * ts-client types are broken, so using any for now
     */
    client: any;
    apiClient: AxiosInstance;
    wallet: DirectSecp256k1Wallet;
    apiUrl: string;
    constructor(rpcUrl: string, privateKey: string, logger: Logger);
    registerDaemonMetadata(manifest: Manifest, queries: MyDaemonMetadataContentQuery[], wasmModule?: string, gas?: string, sdkVersions?: SdkVersion[]): Promise<MsgCreateDaemonMetadataResponse>;
    getDaemonMetadataById(id: string): Promise<DaemonMetadata>;
    unRegisterDaemon(id: string): Promise<MsgUnregisterDaemonResponse>;
    registerDaemonFromManifest(manifest: Manifest, daemonMetadataId: string, chain: string, parameterValues: DaemonParameterMap, gas?: string): Promise<MsgRegisterDaemonResponse>;
    registerDaemon(daemonMetadataId: string, chainType: string, parameterValues: DaemonParameterMap, gas?: string): Promise<MsgRegisterDaemonResponse>;
    createPlaybook(playbook: PlaybookDTO, gas?: string): Promise<MsgCreatePlaybookResponse>;
    updatePlaybook(playbookId: string, playbook: PlaybookDTO, gas?: string): Promise<MsgUpdatePlaybookResponse>;
    /**
     * Get the chain type from the manifest.
     * Exported just for testing purposes
     */
    getChainTypes(manifest: Manifest): Chain_ChainType[];
    private getWallet;
    private registerSniffer;
    private getVcClient;
    private getApiClient;
    private getTxClient;
    private getQueryClient;
    private getAddress;
    private getDecoder;
    private decodeProtobuf;
    private decodeTxMessages;
    private formatError;
    private throwOnError;
    /**
     * Utility function that can be used for debug messages from validation-chain protobuf API.
     * Uncomment if you need to debug messages.
     */
    private inspectMsgData;
    private getTxData;
    private getTxDataOnlyResponse;
}
export default ValidationChainService;
//# sourceMappingURL=index.d.ts.map